﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Drawing.Imaging;
using System.IO;
using System.Net;
using System.Text;
using System.Text.RegularExpressions;
using System.Web;
/// <summary>
/// 字符文本操作类
/// </summary>
public class StringHelper
{
    static private Hashtable _pinyinHash;

    #region static stor.
    static StringHelper()
    {
        _pinyinHash = new Hashtable();
        _pinyinHash.Add(-20319, "a");
        _pinyinHash.Add(-20317, "ai"); _pinyinHash.Add(-20304, "an"); _pinyinHash.Add(-20295, "ang");
        _pinyinHash.Add(-20292, "ao"); _pinyinHash.Add(-20283, "ba"); _pinyinHash.Add(-20265, "bai");
        _pinyinHash.Add(-20257, "ban"); _pinyinHash.Add(-20242, "bang"); _pinyinHash.Add(-20230, "bao");
        _pinyinHash.Add(-20051, "bei"); _pinyinHash.Add(-20036, "ben"); _pinyinHash.Add(-20032, "beng");
        _pinyinHash.Add(-20026, "bi"); _pinyinHash.Add(-20002, "bian"); _pinyinHash.Add(-19990, "biao");
        _pinyinHash.Add(-19986, "bie"); _pinyinHash.Add(-19982, "bin"); _pinyinHash.Add(-19976, "bing");
        _pinyinHash.Add(-19805, "bo"); _pinyinHash.Add(-19784, "bu"); _pinyinHash.Add(-19775, "ca");
        _pinyinHash.Add(-19774, "cai"); _pinyinHash.Add(-19763, "can"); _pinyinHash.Add(-19756, "cang");
        _pinyinHash.Add(-19751, "cao"); _pinyinHash.Add(-19746, "ce"); _pinyinHash.Add(-19741, "ceng");
        _pinyinHash.Add(-19739, "cha"); _pinyinHash.Add(-19728, "chai"); _pinyinHash.Add(-19725, "chan");
        _pinyinHash.Add(-19715, "chang"); _pinyinHash.Add(-19540, "chao"); _pinyinHash.Add(-19531, "che");
        _pinyinHash.Add(-19525, "chen"); _pinyinHash.Add(-19515, "cheng"); _pinyinHash.Add(-19500, "chi");
        _pinyinHash.Add(-19484, "chong"); _pinyinHash.Add(-19479, "chou"); _pinyinHash.Add(-19467, "chu");
        _pinyinHash.Add(-19289, "chuai"); _pinyinHash.Add(-19288, "chuan"); _pinyinHash.Add(-19281, "chuang");
        _pinyinHash.Add(-19275, "chui"); _pinyinHash.Add(-19270, "chun"); _pinyinHash.Add(-19263, "chuo");
        _pinyinHash.Add(-19261, "ci"); _pinyinHash.Add(-19249, "cong"); _pinyinHash.Add(-19243, "cou");
        _pinyinHash.Add(-19242, "cu"); _pinyinHash.Add(-19238, "cuan"); _pinyinHash.Add(-19235, "cui");
        _pinyinHash.Add(-19227, "cun"); _pinyinHash.Add(-19224, "cuo"); _pinyinHash.Add(-19218, "da");
        _pinyinHash.Add(-19212, "dai"); _pinyinHash.Add(-19038, "dan"); _pinyinHash.Add(-19023, "dang");
        _pinyinHash.Add(-19018, "dao"); _pinyinHash.Add(-19006, "de"); _pinyinHash.Add(-19003, "deng");
        _pinyinHash.Add(-18996, "di"); _pinyinHash.Add(-18977, "dian"); _pinyinHash.Add(-18961, "diao");
        _pinyinHash.Add(-18952, "die"); _pinyinHash.Add(-18783, "ding"); _pinyinHash.Add(-18774, "diu");
        _pinyinHash.Add(-18773, "dong"); _pinyinHash.Add(-18763, "dou"); _pinyinHash.Add(-18756, "du");
        _pinyinHash.Add(-18741, "duan"); _pinyinHash.Add(-18735, "dui"); _pinyinHash.Add(-18731, "dun");
        _pinyinHash.Add(-18722, "duo"); _pinyinHash.Add(-18710, "e"); _pinyinHash.Add(-18697, "en");
        _pinyinHash.Add(-18696, "er"); _pinyinHash.Add(-18526, "fa"); _pinyinHash.Add(-18518, "fan");
        _pinyinHash.Add(-18501, "fang"); _pinyinHash.Add(-18490, "fei"); _pinyinHash.Add(-18478, "fen");
        _pinyinHash.Add(-18463, "feng"); _pinyinHash.Add(-18448, "fo"); _pinyinHash.Add(-18447, "fou");
        _pinyinHash.Add(-18446, "fu"); _pinyinHash.Add(-18239, "ga"); _pinyinHash.Add(-18237, "gai");
        _pinyinHash.Add(-18231, "gan"); _pinyinHash.Add(-18220, "gang"); _pinyinHash.Add(-18211, "gao");
        _pinyinHash.Add(-18201, "ge"); _pinyinHash.Add(-18184, "gei"); _pinyinHash.Add(-18183, "gen");
        _pinyinHash.Add(-18181, "geng"); _pinyinHash.Add(-18012, "gong"); _pinyinHash.Add(-17997, "gou");
        _pinyinHash.Add(-17988, "gu"); _pinyinHash.Add(-17970, "gua"); _pinyinHash.Add(-17964, "guai");
        _pinyinHash.Add(-17961, "guan"); _pinyinHash.Add(-17950, "guang"); _pinyinHash.Add(-17947, "gui");
        _pinyinHash.Add(-17931, "gun"); _pinyinHash.Add(-17928, "guo"); _pinyinHash.Add(-17922, "ha");
        _pinyinHash.Add(-17759, "hai"); _pinyinHash.Add(-17752, "han"); _pinyinHash.Add(-17733, "hang");
        _pinyinHash.Add(-17730, "hao"); _pinyinHash.Add(-17721, "he"); _pinyinHash.Add(-17703, "hei");
        _pinyinHash.Add(-17701, "hen"); _pinyinHash.Add(-17697, "heng"); _pinyinHash.Add(-17692, "hong");
        _pinyinHash.Add(-17683, "hou"); _pinyinHash.Add(-17676, "hu"); _pinyinHash.Add(-17496, "hua");
        _pinyinHash.Add(-17487, "huai"); _pinyinHash.Add(-17482, "huan"); _pinyinHash.Add(-17468, "huang");
        _pinyinHash.Add(-17454, "hui"); _pinyinHash.Add(-17433, "hun"); _pinyinHash.Add(-17427, "huo");
        _pinyinHash.Add(-17417, "ji"); _pinyinHash.Add(-17202, "jia"); _pinyinHash.Add(-17185, "jian");
        _pinyinHash.Add(-16983, "jiang"); _pinyinHash.Add(-16970, "jiao"); _pinyinHash.Add(-16942, "jie");
        _pinyinHash.Add(-16915, "jin"); _pinyinHash.Add(-16733, "jing"); _pinyinHash.Add(-16708, "jiong");
        _pinyinHash.Add(-16706, "jiu"); _pinyinHash.Add(-16689, "ju"); _pinyinHash.Add(-16664, "juan");
        _pinyinHash.Add(-16657, "jue"); _pinyinHash.Add(-16647, "jun"); _pinyinHash.Add(-16474, "ka");
        _pinyinHash.Add(-16470, "kai"); _pinyinHash.Add(-16465, "kan"); _pinyinHash.Add(-16459, "kang");
        _pinyinHash.Add(-16452, "kao"); _pinyinHash.Add(-16448, "ke"); _pinyinHash.Add(-16433, "ken");
        _pinyinHash.Add(-16429, "keng"); _pinyinHash.Add(-16427, "kong"); _pinyinHash.Add(-16423, "kou");
        _pinyinHash.Add(-16419, "ku"); _pinyinHash.Add(-16412, "kua"); _pinyinHash.Add(-16407, "kuai");
        _pinyinHash.Add(-16403, "kuan"); _pinyinHash.Add(-16401, "kuang"); _pinyinHash.Add(-16393, "kui");
        _pinyinHash.Add(-16220, "kun"); _pinyinHash.Add(-16216, "kuo"); _pinyinHash.Add(-16212, "la");
        _pinyinHash.Add(-16205, "lai"); _pinyinHash.Add(-16202, "lan"); _pinyinHash.Add(-16187, "lang");
        _pinyinHash.Add(-16180, "lao"); _pinyinHash.Add(-16171, "le"); _pinyinHash.Add(-16169, "lei");
        _pinyinHash.Add(-16158, "leng"); _pinyinHash.Add(-16155, "li"); _pinyinHash.Add(-15959, "lia");
        _pinyinHash.Add(-15958, "lian"); _pinyinHash.Add(-15944, "liang"); _pinyinHash.Add(-15933, "liao");
        _pinyinHash.Add(-15920, "lie"); _pinyinHash.Add(-15915, "lin"); _pinyinHash.Add(-15903, "ling");
        _pinyinHash.Add(-15889, "liu"); _pinyinHash.Add(-15878, "long"); _pinyinHash.Add(-15707, "lou");
        _pinyinHash.Add(-15701, "lu"); _pinyinHash.Add(-15681, "lv"); _pinyinHash.Add(-15667, "luan");
        _pinyinHash.Add(-15661, "lue"); _pinyinHash.Add(-15659, "lun"); _pinyinHash.Add(-15652, "luo");
        _pinyinHash.Add(-15640, "ma"); _pinyinHash.Add(-15631, "mai"); _pinyinHash.Add(-15625, "man");
        _pinyinHash.Add(-15454, "mang"); _pinyinHash.Add(-15448, "mao"); _pinyinHash.Add(-15436, "me");
        _pinyinHash.Add(-15435, "mei"); _pinyinHash.Add(-15419, "men"); _pinyinHash.Add(-15416, "meng");
        _pinyinHash.Add(-15408, "mi"); _pinyinHash.Add(-15394, "mian"); _pinyinHash.Add(-15385, "miao");
        _pinyinHash.Add(-15377, "mie"); _pinyinHash.Add(-15375, "min"); _pinyinHash.Add(-15369, "ming");
        _pinyinHash.Add(-15363, "miu"); _pinyinHash.Add(-15362, "mo"); _pinyinHash.Add(-15183, "mou");
        _pinyinHash.Add(-15180, "mu"); _pinyinHash.Add(-15165, "na"); _pinyinHash.Add(-15158, "nai");
        _pinyinHash.Add(-15153, "nan"); _pinyinHash.Add(-15150, "nang"); _pinyinHash.Add(-15149, "nao");
        _pinyinHash.Add(-15144, "ne"); _pinyinHash.Add(-15143, "nei"); _pinyinHash.Add(-15141, "nen");
        _pinyinHash.Add(-15140, "neng"); _pinyinHash.Add(-15139, "ni"); _pinyinHash.Add(-15128, "nian");
        _pinyinHash.Add(-15121, "niang"); _pinyinHash.Add(-15119, "niao"); _pinyinHash.Add(-15117, "nie");
        _pinyinHash.Add(-15110, "nin"); _pinyinHash.Add(-15109, "ning"); _pinyinHash.Add(-14941, "niu");
        _pinyinHash.Add(-14937, "nong"); _pinyinHash.Add(-14933, "nu"); _pinyinHash.Add(-14930, "nv");
        _pinyinHash.Add(-14929, "nuan"); _pinyinHash.Add(-14928, "nue"); _pinyinHash.Add(-14926, "nuo");
        _pinyinHash.Add(-14922, "o"); _pinyinHash.Add(-14921, "ou"); _pinyinHash.Add(-14914, "pa");
        _pinyinHash.Add(-14908, "pai"); _pinyinHash.Add(-14902, "pan"); _pinyinHash.Add(-14894, "pang");
        _pinyinHash.Add(-14889, "pao"); _pinyinHash.Add(-14882, "pei"); _pinyinHash.Add(-14873, "pen");
        _pinyinHash.Add(-14871, "peng"); _pinyinHash.Add(-14857, "pi"); _pinyinHash.Add(-14678, "pian");
        _pinyinHash.Add(-14674, "piao"); _pinyinHash.Add(-14670, "pie"); _pinyinHash.Add(-14668, "pin");
        _pinyinHash.Add(-14663, "ping"); _pinyinHash.Add(-14654, "po"); _pinyinHash.Add(-14645, "pu");
        _pinyinHash.Add(-14630, "qi"); _pinyinHash.Add(-14594, "qia"); _pinyinHash.Add(-14429, "qian");
        _pinyinHash.Add(-14407, "qiang"); _pinyinHash.Add(-14399, "qiao"); _pinyinHash.Add(-14384, "qie");
        _pinyinHash.Add(-14379, "qin"); _pinyinHash.Add(-14368, "qing"); _pinyinHash.Add(-14355, "qiong");
        _pinyinHash.Add(-14353, "qiu"); _pinyinHash.Add(-14345, "qu"); _pinyinHash.Add(-14170, "quan");
        _pinyinHash.Add(-14159, "que"); _pinyinHash.Add(-14151, "qun"); _pinyinHash.Add(-14149, "ran");
        _pinyinHash.Add(-14145, "rang"); _pinyinHash.Add(-14140, "rao"); _pinyinHash.Add(-14137, "re");
        _pinyinHash.Add(-14135, "ren"); _pinyinHash.Add(-14125, "reng"); _pinyinHash.Add(-14123, "ri");
        _pinyinHash.Add(-14122, "rong"); _pinyinHash.Add(-14112, "rou"); _pinyinHash.Add(-14109, "ru");
        _pinyinHash.Add(-14099, "ruan"); _pinyinHash.Add(-14097, "rui"); _pinyinHash.Add(-14094, "run");
        _pinyinHash.Add(-14092, "ruo"); _pinyinHash.Add(-14090, "sa"); _pinyinHash.Add(-14087, "sai");
        _pinyinHash.Add(-14083, "san"); _pinyinHash.Add(-13917, "sang"); _pinyinHash.Add(-13914, "sao");
        _pinyinHash.Add(-13910, "se"); _pinyinHash.Add(-13907, "sen"); _pinyinHash.Add(-13906, "seng");
        _pinyinHash.Add(-13905, "sha"); _pinyinHash.Add(-13896, "shai"); _pinyinHash.Add(-13894, "shan");
        _pinyinHash.Add(-13878, "shang"); _pinyinHash.Add(-13870, "shao"); _pinyinHash.Add(-13859, "she");
        _pinyinHash.Add(-13847, "shen"); _pinyinHash.Add(-13831, "sheng"); _pinyinHash.Add(-13658, "shi");
        _pinyinHash.Add(-13611, "shou"); _pinyinHash.Add(-13601, "shu"); _pinyinHash.Add(-13406, "shua");
        _pinyinHash.Add(-13404, "shuai"); _pinyinHash.Add(-13400, "shuan"); _pinyinHash.Add(-13398, "shuang");
        _pinyinHash.Add(-13395, "shui"); _pinyinHash.Add(-13391, "shun"); _pinyinHash.Add(-13387, "shuo");
        _pinyinHash.Add(-13383, "si"); _pinyinHash.Add(-13367, "song"); _pinyinHash.Add(-13359, "sou");
        _pinyinHash.Add(-13356, "su"); _pinyinHash.Add(-13343, "suan"); _pinyinHash.Add(-13340, "sui");
        _pinyinHash.Add(-13329, "sun"); _pinyinHash.Add(-13326, "suo"); _pinyinHash.Add(-13318, "ta");
        _pinyinHash.Add(-13147, "tai"); _pinyinHash.Add(-13138, "tan"); _pinyinHash.Add(-13120, "tang");
        _pinyinHash.Add(-13107, "tao"); _pinyinHash.Add(-13096, "te"); _pinyinHash.Add(-13095, "teng");
        _pinyinHash.Add(-13091, "ti"); _pinyinHash.Add(-13076, "tian"); _pinyinHash.Add(-13068, "tiao");
        _pinyinHash.Add(-13063, "tie"); _pinyinHash.Add(-13060, "ting"); _pinyinHash.Add(-12888, "tong");
        _pinyinHash.Add(-12875, "tou"); _pinyinHash.Add(-12871, "tu"); _pinyinHash.Add(-12860, "tuan");
        _pinyinHash.Add(-12858, "tui"); _pinyinHash.Add(-12852, "tun"); _pinyinHash.Add(-12849, "tuo");
        _pinyinHash.Add(-12838, "wa"); _pinyinHash.Add(-12831, "wai"); _pinyinHash.Add(-12829, "wan");
        _pinyinHash.Add(-12812, "wang"); _pinyinHash.Add(-12802, "wei"); _pinyinHash.Add(-12607, "wen");
        _pinyinHash.Add(-12597, "weng"); _pinyinHash.Add(-12594, "wo"); _pinyinHash.Add(-12585, "wu");
        _pinyinHash.Add(-12556, "xi"); _pinyinHash.Add(-12359, "xia"); _pinyinHash.Add(-12346, "xian");
        _pinyinHash.Add(-12320, "xiang"); _pinyinHash.Add(-12300, "xiao"); _pinyinHash.Add(-12120, "xie");
        _pinyinHash.Add(-12099, "xin"); _pinyinHash.Add(-12089, "xing"); _pinyinHash.Add(-12074, "xiong");
        _pinyinHash.Add(-12067, "xiu"); _pinyinHash.Add(-12058, "xu"); _pinyinHash.Add(-12039, "xuan");
        _pinyinHash.Add(-11867, "xue"); _pinyinHash.Add(-11861, "xun"); _pinyinHash.Add(-11847, "ya");
        _pinyinHash.Add(-11831, "yan"); _pinyinHash.Add(-11798, "yang"); _pinyinHash.Add(-11781, "yao");
        _pinyinHash.Add(-11604, "ye"); _pinyinHash.Add(-11589, "yi"); _pinyinHash.Add(-11536, "yin");
        _pinyinHash.Add(-11358, "ying"); _pinyinHash.Add(-11340, "yo"); _pinyinHash.Add(-11339, "yong");
        _pinyinHash.Add(-11324, "you"); _pinyinHash.Add(-11303, "yu"); _pinyinHash.Add(-11097, "yuan");
        _pinyinHash.Add(-11077, "yue"); _pinyinHash.Add(-11067, "yun"); _pinyinHash.Add(-11055, "za");
        _pinyinHash.Add(-11052, "zai"); _pinyinHash.Add(-11045, "zan"); _pinyinHash.Add(-11041, "zang");
        _pinyinHash.Add(-11038, "zao"); _pinyinHash.Add(-11024, "ze"); _pinyinHash.Add(-11020, "zei");
        _pinyinHash.Add(-11019, "zen"); _pinyinHash.Add(-11018, "zeng"); _pinyinHash.Add(-11014, "zha");
        _pinyinHash.Add(-10838, "zhai"); _pinyinHash.Add(-10832, "zhan"); _pinyinHash.Add(-10815, "zhang");
        _pinyinHash.Add(-10800, "zhao"); _pinyinHash.Add(-10790, "zhe"); _pinyinHash.Add(-10780, "zhen");
        _pinyinHash.Add(-10764, "zheng"); _pinyinHash.Add(-10587, "zhi"); _pinyinHash.Add(-10544, "zhong");
        _pinyinHash.Add(-10533, "zhou"); _pinyinHash.Add(-10519, "zhu"); _pinyinHash.Add(-10331, "zhua");
        _pinyinHash.Add(-10329, "zhuai"); _pinyinHash.Add(-10328, "zhuan"); _pinyinHash.Add(-10322, "zhuang");
        _pinyinHash.Add(-10315, "zhui"); _pinyinHash.Add(-10309, "zhun"); _pinyinHash.Add(-10307, "zhuo");
        _pinyinHash.Add(-10296, "zi"); _pinyinHash.Add(-10281, "zong"); _pinyinHash.Add(-10274, "zou");
        _pinyinHash.Add(-10270, "zu"); _pinyinHash.Add(-10262, "zuan"); _pinyinHash.Add(-10260, "zui");
        _pinyinHash.Add(-10256, "zun"); _pinyinHash.Add(-10254, "zuo"); _pinyinHash.Add(-10247, "zz");
    }
    #endregion

    /// <summary>
    /// 获得汉字的拼音，如果输入的是英文字符将原样输出，中文标点符号将被忽略
    /// </summary>
    /// <param name="chineseChars">汉字字符串</param>
    /// <returns>拼音</returns>
    public static string GetPinyin(string chineseChars)
    {
        byte[] byteArray = System.Text.Encoding.Default.GetBytes(chineseChars);
        int byteValue;
        StringBuilder sb = new StringBuilder(chineseChars.Length * 4);
        for (int i = 0; i < byteArray.Length; i++)
        {
            byteValue = (int)byteArray[i];
            if (byteValue > 160)
            {
                byteValue = byteValue * 256 + byteArray[++i] - 65536;
                sb.Append(GetPinyin(byteValue));
            }
            else
            {
                sb.Append((char)byteValue);
            }
        }
        Regex reg = new Regex(@"[^a-zA-Z0-9]+");
        string result = reg.Replace(sb.ToString(), "-");
        if (result.EndsWith("-")) 
        {
            result = result.Substring(0, result.Length - 1);
        }
        return result;
    }

    /// <summary>
    /// 获得汉字拼音的简写，即每一个汉字的拼音的首字母组成的串，如果输入的是英文字符将原样输出，中文标点符号将被忽略
    /// </summary>
    /// <param name="chineseChars">汉字字符串</param>
    /// <returns>拼音简写</returns>
    public static string GetShortPinyin(string chineseChars)
    {
        byte[] byteArray = System.Text.Encoding.Default.GetBytes(chineseChars);
        int byteValue;
        StringBuilder sb = new StringBuilder(chineseChars.Length * 4);
        for (int i = 0; i < byteArray.Length; i++)
        {
            byteValue = (int)byteArray[i];
            if (byteValue > 160)
            {
                byteValue = byteValue * 256 + byteArray[++i] - 65536;
                string charPinyin = GetPinyin(byteValue);
                if (!string.IsNullOrEmpty(charPinyin))
                {
                    charPinyin = new string(charPinyin[0], 1);
                }
                sb.Append(charPinyin);
            }
            else
            {
                sb.Append((char)byteValue);
            }
        }
        Regex reg = new Regex(@"[^a-zA-Z0-9]+");
        string result = reg.Replace(sb.ToString(), "-");
        if (result.EndsWith("-"))
        {
            result = result.Substring(0, result.Length - 1);
        }
        return result;
    }

    static private string GetPinyin(int charValue)
    {
        if (charValue < -20319 || charValue > -10247)
            return "";

        while (!_pinyinHash.ContainsKey(charValue))
            charValue--;

        return (string)_pinyinHash[charValue];
    }



    #region 功能描述：将字符串转换成参数。
    /// <summary>
    /// 功能描述：将字符串转换成参数。
    /// </summary>
    /// <param name="str">需转换的字符串</param>
    /// <returns></returns>
    public static string paramChg(string str)
    {
        str = "@" + str;
        return str;
    }
    #endregion

    #region  功能描述：从字符串中的尾部删除指定的字符串。
    /// <summary>
    /// 功能描述：从字符串中的尾部删除指定的字符串。
    /// </summary>
    /// <param name="sourceString">原字符串</param>
    /// <param name="removedString">移除字符串</param>
    /// <returns>留下的字符串</returns>
    public static string Remove(string sourceString, string removedString)
    {
        try
        {
            if (sourceString.IndexOf(removedString) == -1)
                throw new Exception("原字符串中不包含移除字符串！");
            string result = sourceString;
            int LengthOfsourceString = sourceString.Length;
            int LengthOfremovedString = removedString.Length;
            int startIndex = LengthOfsourceString - LengthOfremovedString;
            string sourceStringSub = sourceString.Substring(startIndex);
            if (sourceStringSub.ToUpper() == removedString.ToUpper())
            {
                result = sourceString.Remove(startIndex, LengthOfremovedString);
            }
            return result;
        }
        catch
        {
            return sourceString;
        }

    }
    #endregion

    #region 功能描述：从字符串中的指定位置删除指定的字符串。
    /// <summary>
    /// 功能描述：从字符串中的指定位置删除指定的字符串。
    /// </summary>
    /// <param name="sourceString">原字符串</param>
    /// <param name="removedString">移除字符串</param>
    /// <returns>留下的字符串</returns>
    public static string StrRemove(string sourceString, string removedString)
    {
        try
        {
            if (sourceString.IndexOf(removedString) == -1)
                throw new Exception("原字符串中不包含移除字符串！");
            string result = sourceString;
            int LengthOfremovedString = removedString.Length;
            if (sourceString.IndexOf(removedString) > 0)
            {
                int startIndex = sourceString.IndexOf(removedString);
                result = sourceString.Remove(startIndex, LengthOfremovedString);
            }
            return result;
        }
        catch
        {
            return sourceString;
        }

    }
    #endregion

    #region 功能描述：获取拆分符右边的字符串。
    /// <summary>
    /// 功能描述：获取拆分符右边的字符串。
    /// </summary>
    /// <param name="sourceString">原字符串</param>
    /// <param name="splitChar">拆分字符</param>
    /// <returns>右边的字符串</returns>
    public static string RightSplit(string sourceString, char splitChar)
    {
        string result = null;
        string[] tempStr = sourceString.Split(splitChar);
        if (tempStr.Length > 0)
        {
            result = tempStr[tempStr.Length - 1].ToString();
        }
        return result;

    }
    #endregion

    #region 功能描述：获取拆分符左边的字符串。
    /// <summary>
    /// 功能描述：获取拆分符左边的字符串。
    /// </summary>
    /// <param name="sourceString">原字符串</param>
    /// <param name="splitChar">拆分字符</param>
    /// <returns>左边的字符串</returns>
    public static string LeftSplit(string sourceString, char splitChar)
    {
        string result = null;
        string[] tempStr = sourceString.Split(splitChar);
        if (tempStr.Length > 0)
        {
            result = tempStr[0].ToString();
        }
        return result;

    }
    #endregion

    #region 功能描述：去掉最后一个逗号后面的字符串。
    /// <summary>
    /// 功能描述：去掉最后一个逗号后面的字符串。
    /// </summary>
    /// <param name="sourceString">原字符串</param>
    /// <param name="splitChar">拆分字符</param>
    /// <returns>左边的字符串</returns>
    public static string DelLsatComma(string sourceString)
    {
        if (sourceString.IndexOf(",") == -1)
        {
            return sourceString;
        }
        return sourceString.Substring(0, sourceString.LastIndexOf(","));

    }
    #endregion

    #region 功能描述：删除不可见字符。
    /// <summary>
    /// 功能描述：删除不可见字符。
    /// </summary>
    /// <param name="sourceString">原字符串</param>
    /// <returns></returns>
    public static string DeleteUnVisibleChar(string sourceString)
    {
        System.Text.StringBuilder strBuilder = new System.Text.StringBuilder(131);
        for (int i = 0; i < sourceString.Length; i++)
        {
            int Unicode = sourceString[i];
            if (Unicode >= 16)
            {
                strBuilder.Append(sourceString[i].ToString());
            }
        }
        return strBuilder.ToString();
    }
    #endregion

    #region 功能描述：获取数组元素的合并字符串。
    /// <summary>
    /// 功能描述：获取数组元素的合并字符串。
    /// </summary>
    /// <param name="stringArray">字符串数组</param>
    /// <returns></returns>
    public static string GetArrayString(string[] stringArray)
    {
        string totalString = null;
        for (int i = 0; i < stringArray.Length; i++)
        {
            totalString = totalString + stringArray[i];
        }
        return totalString;
    }
    #endregion

    #region 功能描述：获取某一字符串在字符串数组中出现的次数。
    /// <summary>
    /// 功能描述：获取某一字符串在字符串数组中出现的次数。
    /// </summary>
    /// <param name="stringArray">字符串数组</param>
    /// <param name="findString">某一字符串</param>
    /// <returns></returns>
    public static int GetStringCount(string[] stringArray, string findString)
    {
        int count = 0;
        string totalString = GetArrayString(stringArray);
        int findStringLength = findString.Length;
        string subString = totalString;
        while (subString.IndexOf(findString) >= 0)
        {
            subString = subString.Substring(subString.IndexOf(findString) + findStringLength);
            count += 1;
        }
        return count;
    }
    #endregion

    #region 功能描述：获取某一字符串在字符串中出现的次数。
    /// <summary>
    /// 功能描述：获取某一字符串在字符串中出现的次数。
    /// </summary>
    /// <param name="sourceString">字符串</param>
    /// <param name="findString">某一字符串</param>
    /// <returns></returns>
    public static int GetStringCount(string sourceString, string findString)
    {
        int count = 0;
        int findStringLength = findString.Length;
        string subString = sourceString;
        while (subString.IndexOf(findString) >= 0)
        {
            subString = subString.Substring(subString.IndexOf(findString) + findStringLength);
            count += 1;
        }
        return count;
    }
    #endregion

    #region 功能描述：截取从startString开始到原字符串结尾的所有字符。
    /// <summary>
    /// 功能描述：截取从startString开始到原字符串结尾的所有字符。
    /// </summary>
    /// <param name="sourceString">字符串</param>
    /// <param name="startString">某一字符串</param>
    /// <returns></returns>
    public static string GetSubstring(string sourceString, string startString)
    {
        int startIndex = sourceString.IndexOf(startString);
        if (startIndex > 0)
            return sourceString.Substring(startIndex);
        return sourceString;
    }
    #endregion

    #region 功能描述：按字节数取出字符串的长度。
    /// <summary>
    /// 功能描述：按字节数取出字符串的长度。
    /// </summary>
    /// <param name="sourceString">要计算的字符串</param>
    /// <returns>字符串的字节数</returns>
    public static int GetByteCount(string sourceString)
    {
        int itnCharCount = 0;
        for (int i = 0; i < sourceString.Length; i++)
        {
            if (System.Text.UTF8Encoding.UTF8.GetByteCount(sourceString.Substring(i, 1)) == 3)
            {
                itnCharCount = itnCharCount + 2;
            }
            else
            {
                itnCharCount = itnCharCount + 1;
            }
        }
        return itnCharCount;
    }
    #endregion

    #region 功能描述：按字节数要在字符串的位置。
    /// <summary>
    /// 功能描述：按字节数要在字符串的位置。
    /// </summary>
    /// <param name="intIns">字符串的位置</param>
    /// <param name="strTmp">要计算的字符串</param>
    /// <returns>字节的位置</returns>
    public static int GetByteIndex(int intIns, string strTmp)
    {
        int intReIns = 0;
        if (strTmp.Trim() == "")
        {
            return intIns;
        }
        for (int i = 0; i < strTmp.Length; i++)
        {
            if (System.Text.UTF8Encoding.UTF8.GetByteCount(strTmp.Substring(i, 1)) == 3)
            {
                intReIns = intReIns + 2;
            }
            else
            {
                intReIns = intReIns + 1;
            }
            if (intReIns >= intIns)
            {
                intReIns = i + 1;
                break;
            }
        }
        return intReIns;
    }
    #endregion

    #region 返回路径分割符号"\"最后一个字符串。
    /// <summary>
    /// 返回路径分割符号"\"最后一个字符串。
    /// </summary>
    /// <param name="sourceStr">原字符串</param>
    /// <param name="splitChar">分割符号</param>
    /// <returns></returns>
    public static string getLastStr(string sourceStr, char splitChar)
    {
        string[] strArr = sourceStr.Split(splitChar);
        string lastStr = strArr[strArr.Length - 1];
        if (lastStr == "")
            return strArr[strArr.Length - 2];
        return lastStr;
    }
    #endregion

    #region 获取路径最后一个分隔符"\"左边的全部字符串
    /// <summary>
    /// 获取路径最后一个分隔符"\"左边的全部字符串
    /// </summary>
    /// <param name="sourceStr"></param>
    /// <param name="splitChar">分隔符</param>
    /// <returns></returns>
    public static string getLeftStr(string sourceStr, char splitChar)
    {
        string[] strArr = sourceStr.Split(splitChar);
        int length = sourceStr.Length - getLastStr(sourceStr, splitChar).Length;
        string leftStr = sourceStr.Substring(0, length-1);
        return leftStr;
    }
    #endregion

    #region  编码字符串
    /// <summary>
    /// 编码字符串
    /// </summary>
    /// <param name="str"></param>
    /// <returns></returns>
    public static string Encode(string str)
    {
        str = str.Replace("<p>", "<br>");
        str = str.Replace("</p>", "");
        str = str.Replace(".", "．");
        str = str.Replace("'", "''");
        str = str.Replace(":", "：");
        //   str = str.Replace("<", "&lt;");
        //   str = str.Replace(">", "&gt;");
        str = str.Replace("//", "／／");
        str = str.Replace("http", "ｈｔｔｐ");
        str = str.Replace("js", "ｊｓ");
        str = str.Replace("gif", "ｇｉｆ");
        return str;
    }
    #endregion

    #region 解码字符串
    /// <summary>
    /// 解码字符串
    /// </summary>
    /// <param name="str"></param>
    /// <returns></returns>
    public static string Decode(string str)
    {
        str = str.Replace("<br>", "\n");
        //str = str.Replace("&gt;", ">");
        //str = str.Replace("&lt;", "<");
        str = str.Replace("&nbsp;", " ");
        str = str.Replace("&quot;", "\"");
        return str;
    }
    #endregion

    #region 文本域的html编码
    /// <summary>
    /// 文本域的html编码
    /// </summary>
    /// <param name="str"></param>
    /// <returns></returns>
    public static string HtmlEncode(string str)
    {
        str = str.Replace("'", "''");
        str = str.Replace("\"", "&quot;");
        str = str.Replace(" ", "&nbsp;");
        //   str = str.Replace("<", "&lt;");
        //   str = str.Replace(">", "&gt;");
        str = str.Replace("\n", "<br>");
        str = str.Replace("//", "／／");
        str = str.Replace("http", "ｈｔｔｐ");
        str = str.Replace("js", "ｊｓ");
        str = str.Replace("gif", "ｇｉｆ");
        str = str.Replace("com", "ｃｏｍ");
        str = str.Replace(".", "．");
        return str;
    }
    #endregion

    #region 文本域的html解码
    /// <summary>
    /// 文本域的html解码
    /// </summary>
    /// <param name="str"></param>
    /// <returns></returns>
    public static string HtmlDecode(string str)
    {
        //   str = str.Replace("&gt;", ">");
        //   str = str.Replace("&lt;", "<");
        str = str.Replace("&nbsp;", " ");
        str = str.Replace("&quot;", "\"");
        str = str.Replace("''", "'");
        str = str.Replace("<br>", "\n");
        return str;
    }
    #endregion

    #region 出去空格，并见对尖括号内的空格加入。
    /// <summary>
    /// 出去空格，并见对尖括号内的空格加入。
    /// </summary>
    /// <param name="contStr"></param>
    /// <returns></returns>
    public static string ReplaceStr(string contStr)
    {
        contStr = System.Text.RegularExpressions.Regex.Replace(contStr, "\\s", "&nbsp;");
        int y, z;
        z = 0;
        int i = 0;
        do
        {
            y = contStr.IndexOf("<", z);
            if (y >= 0)
            {
                z = contStr.IndexOf(">", y);
                if (z >= 0)
                {
                    i += contStr.Substring(y, z - y + 1).Replace("&nbsp;", " ").Length + 4; //统计超级链接标签占用的字符数
                    string tStr1, tStr2;
                    tStr1 = contStr.Substring(0, z + 1);
                    tStr2 = contStr.Substring(z + 1);
                    contStr = tStr1.Replace(tStr1.Substring(y, z - y + 1), tStr1.Substring(y, z - y + 1).Replace("&nbsp;", " ")) + tStr2;
                }
                else
                {

                    z = y + 1;
                    if (z > contStr.Length - 1)
                        break;
                }
            }
        }
        while (y >= 0 && z <= contStr.Length - 1);
        return contStr;
    }
    #endregion

    #region 左截取指定长度并附加指定值
    /// <summary>
    /// 左截取指定长度并附加指定值
    /// </summary>
    /// <param name="sourcestr">源字符串</param>
    /// <param name="addstr">要附加的值如 ...等</param>
    /// <param name="len">长度</param>
    /// <returns>新字符串</returns>
    public static string Getleftn(string sourcestr, string addstr, int len)
    {
        string val = sourcestr;
        if (val.Length > len)
        {
            val = val.Substring(0, len) + addstr;
        }
        return val;
    }
    #endregion

    public static string Substr(string str, int len)
    {
        if (str.Trim().Length > len)
        {
            return str.Substring(0, len);
        }
        else
            return str;
    }
    public static string Substr(string str, int len, string straddend)
    {
        if (str.Trim().Length > len)
        {
            return str.Substring(0, len) + straddend;
        }
        else
            return str;
    }
    public static string Removestrright(string str, int len)
    {
        int strlen = str.Length;
        if (strlen >= len)
        {
            return str.Substring(0, strlen - len);
        }
        else
            return str;
    }

    public static string Nohtml(string Htmlstring)
    {

        //删除脚本   
        Htmlstring = Regex.Replace(Htmlstring, @"<script[^>]*?>.*?</script>", "", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"<BR>", "[br]", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"<BR/>", "[br]", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"<br>", "[br]", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"<br />", "[br]", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"<br /><br />", "", RegexOptions.IgnoreCase);
        //删除HTML   
        Htmlstring = Regex.Replace(Htmlstring, @"<(.[^>]*)>", "", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"([\r\n])[\s]+", "", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"-->", "", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"<!--.*", "", RegexOptions.IgnoreCase);

        Htmlstring = Regex.Replace(Htmlstring, @"&(quot|#34);", "\"", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"&(amp|#38);", "&", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"&(lt|#60);", "<", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"&(gt|#62);", ">", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"&(nbsp|#160);", "   ", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"&(iexcl|#161);", "\xa1", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"&(cent|#162);", "\xa2", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"&(pound|#163);", "\xa3", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"&(copy|#169);", "\xa9", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"&#(\d+);", "", RegexOptions.IgnoreCase);

        Htmlstring.Replace("<", "");
        Htmlstring.Replace(">", "");
        Htmlstring.Replace("\r\n", "");
        Htmlstring = HttpContext.Current.Server.HtmlEncode(Htmlstring).Trim();
        Htmlstring = Regex.Replace(Htmlstring, @"\[br\]\[br\]", "", RegexOptions.IgnoreCase);
        Htmlstring = Regex.Replace(Htmlstring, @"\[br\]", "<br />", RegexOptions.IgnoreCase);
        return Htmlstring;

    }
    public static string createbianhao()
    {
        string x = DateTime.Now.ToString();
        x = x.Replace(":", "");
        x = x.Replace("-", "");
        x = x.Replace("/", "");
        x = x.Replace(" ", "");
        return x;
    }
    public static string CutString(string inputString, int len)
    {
        string result;
        if (string.IsNullOrEmpty(inputString))
        {
            result = "";
        }
        else
        {
            inputString = DropHTML(inputString);
            ASCIIEncoding ascii = new ASCIIEncoding();
            int tempLen = 0;
            string tempString = "";
            byte[] s = ascii.GetBytes(inputString);
            for (int i = 0; i < s.Length; i++)
            {
                if (s[i] == 63)
                {
                    tempLen += 2;
                }
                else
                {
                    tempLen++;
                }
                try
                {
                    tempString += inputString.Substring(i, 1);
                }
                catch
                {
                    break;
                }
                if (tempLen > len)
                {
                    break;
                }
            }
            byte[] mybyte = Encoding.Default.GetBytes(inputString);
            if (mybyte.Length > len)
            {
                tempString += "…";
            }
            result = tempString;
        }
        return result;
    }
    public static string DropHTML(string Htmlstring)
    {
        string result;
        if (string.IsNullOrEmpty(Htmlstring))
        {
            result = "";
        }
        else
        {
            Htmlstring = Regex.Replace(Htmlstring, "<script[^>]*?>.*?</script>", "", RegexOptions.IgnoreCase);
            Htmlstring = Regex.Replace(Htmlstring, "<(.[^>]*)>", "", RegexOptions.IgnoreCase);
            Htmlstring = Regex.Replace(Htmlstring, "([\\r\\n])[\\s]+", "", RegexOptions.IgnoreCase);
            Htmlstring = Regex.Replace(Htmlstring, "-->", "", RegexOptions.IgnoreCase);
            Htmlstring = Regex.Replace(Htmlstring, "<!--.*", "", RegexOptions.IgnoreCase);
            Htmlstring = Regex.Replace(Htmlstring, "&(quot|#34);", "\"", RegexOptions.IgnoreCase);
            Htmlstring = Regex.Replace(Htmlstring, "&(amp|#38);", "&", RegexOptions.IgnoreCase);
            Htmlstring = Regex.Replace(Htmlstring, "&(lt|#60);", "<", RegexOptions.IgnoreCase);
            Htmlstring = Regex.Replace(Htmlstring, "&(gt|#62);", ">", RegexOptions.IgnoreCase);
            Htmlstring = Regex.Replace(Htmlstring, "&(nbsp|#160);", " ", RegexOptions.IgnoreCase);
            Htmlstring = Regex.Replace(Htmlstring, "&(iexcl|#161);", "¡", RegexOptions.IgnoreCase);
            Htmlstring = Regex.Replace(Htmlstring, "&(cent|#162);", "¢", RegexOptions.IgnoreCase);
            Htmlstring = Regex.Replace(Htmlstring, "&(pound|#163);", "£", RegexOptions.IgnoreCase);
            Htmlstring = Regex.Replace(Htmlstring, "&(copy|#169);", "©", RegexOptions.IgnoreCase);
            Htmlstring = Regex.Replace(Htmlstring, "&#(\\d+);", "", RegexOptions.IgnoreCase);
            Htmlstring.Replace("<", "");
            Htmlstring.Replace(">", "");
            Htmlstring.Replace("\r\n", "");
            Htmlstring = HttpContext.Current.Server.HtmlEncode(Htmlstring).Trim();
            result = Htmlstring;
        }
        return result;
    }
    public static string DropHTML(string Htmlstring, int strLen)
    {
        return CutString(DropHTML(Htmlstring), strLen);
    }
    #region 功能描述：判断是否是本地。
    /// <summary>
    /// 功能描述：判断是否是本地。
    /// </summary>
    /// <param name="str">判断是否是本地</param>
    /// <returns></returns>
    public static bool Islocalhost()
    {
        HttpContext context = HttpContext.Current;
        string url = context.Request.Url.Host;
        if (url.Contains("localhost"))
        {
            return true;
        }
        else 
        {
            return false;
        }
    }
    #endregion
    // <summary>
    /// 替换下载远程图片及入库操作
    /// </summary>
    /// <param name="strInput">内容</param>
    /// <returns>返回string类型;替换后的内容</returns>
    public static string ReplaceRemoteUrl(string strInput, string url)
    {
        string tempFilePath = "";
        string outStr;
        outStr = strInput;
        //获取远程图片url集合
        EC.FileObj.FolderCreate(url);//创建目录
        string _pattern = @"(http|https|ftp|rtsp|mms):(\/\/|\\\\){1}((([\w-])+[.]){1,}(net|com|cn|org|cc|tv|[0-9]{1,3}))([^\?\s]*\/)(([^\?\s])+[.]{1}(gif|jpg|png|bmp))";
        MatchCollection found = null;
        RegexOptions TheOptions;
        TheOptions = RegexOptions.Singleline | RegexOptions.IgnoreCase;
        Regex r = new Regex(_pattern, TheOptions);
        found = r.Matches(strInput);
        foreach (Match m in found)
        {
            tempFilePath = "";

            if (m.Value.Length > 0)
            {
                tempFilePath = downRemoteImg(url, m.Value);
                //如果下载成功
                if (tempFilePath.Length > 0)
                {
                    outStr = outStr.Replace(m.Value, tempFilePath);
                }
            }
        }

        return outStr;
    }
    #region 获取指定内容中的图片链接
    public static string RemoteUrl(string info, string names)
    {
        string outStr;
        outStr = info;
        string _pattern = @"(<img )(.[^>]*)([^\?\s]*\/)(([^\?\s])+[.]{1}(gif|jpg|png|bmp))(.[^>]*)(>)";
        MatchCollection found = null;
        RegexOptions TheOptions;
        TheOptions = RegexOptions.Singleline | RegexOptions.IgnoreCase;
        Regex r = new Regex(_pattern, TheOptions);
        found = r.Matches(info);
        int i = 1;
        foreach (Match m in found)
        {
            if (m.Value.Length > 0)
            {
                //EC.FileObj.GetFileAttibes(m.Value);

                string img = m.Value.Substring(m.Value.IndexOf("src") + 5, m.Value.Length - m.Value.IndexOf("src") - 5).ToLower();
                if (img.IndexOf(".jpg") > 0)
                {
                    img = img.Substring(0, img.IndexOf(".jpg") + 4);
                }
                else if (img.IndexOf(".gif") > 0)
                {
                    img = img.Substring(0, img.IndexOf(".gif") + 4);
                }
                else if (img.IndexOf(".bmp") > 0)
                {
                    img = img.Substring(0, img.IndexOf(".bmp") + 4);
                }
                else
                {
                    img = img.Substring(0, img.IndexOf(".png") + 4);
                }
                string P_img = "<img src=\"" + img + "\" id=\"imgTip\" title=\"" + names + "-" + i + EC.FileObj.GetFileAttibes(img) + "\"/>";
                outStr = outStr.Replace(m.Value, P_img);
                i++;
            }

        }
        return outStr;
    }
    #endregion
    #region 获取指定内容中的图片链接集合
    public static string[] RemoteUrlArr(string info)
    {

        string _pattern = @"(<img )(.[^>]*)([^\?\s]*\/)(([^\?\s])+[.]{1}(gif|jpg|png|bmp))(.[^>]*)(>)";
        MatchCollection found = null;
        RegexOptions TheOptions;
        TheOptions = RegexOptions.Singleline | RegexOptions.IgnoreCase;
        Regex r = new Regex(_pattern, TheOptions);
        found = r.Matches(info);
        int i = 0;
        string[] outStr = new string[found.Count];
        foreach (Match m in found)
        {
            if (m.Value.Length > 0)
            {
                //EC.FileObj.GetFileAttibes(m.Value);

                string img = m.Value.Substring(m.Value.IndexOf("src") + 5, m.Value.Length - m.Value.IndexOf("src") - 5).ToLower();
                if (img.IndexOf(".jpg") > 0)
                {
                    img = img.Substring(0, img.IndexOf(".jpg") + 4);
                }
                else if (img.IndexOf(".gif") > 0)
                {
                    img = img.Substring(0, img.IndexOf(".gif") + 4);
                }
                else if (img.IndexOf(".bmp") > 0)
                {
                    img = img.Substring(0, img.IndexOf(".bmp") + 4);
                }
                else
                {
                    img = img.Substring(0, img.IndexOf(".png") + 4);
                }
                outStr[i] = img;
                i++;
            }

        }
        return outStr;
    }
    #endregion
    public static string stripHtml(string strHtml)
    {
        string _pattern = @"(<img )(.[^>]*)([^\?\s]*\/)(([^\?\s])+[.]{1}(gif|jpg|png|bmp))(.[^>]*)(>)";
        Regex objRegExp = new Regex(_pattern);
        string strOutput = objRegExp.Replace(strHtml, "");
        return strOutput.Replace("<br />", "");
    }
    public static string delReplaceRemoteUrl(string strInput)
    {
        string outStr;
        outStr = strInput;
        //获取远程图片url集合 
        string _pattern = @"([^\?\s]uploads*\/)(([^\?\s])+[.]{1}(gif|jpg|png|bmp))";
        MatchCollection found = null;
        RegexOptions TheOptions;
        TheOptions = RegexOptions.Singleline | RegexOptions.IgnoreCase;
        Regex r = new Regex(_pattern, TheOptions);
        found = r.Matches(strInput);
        foreach (Match m in found)
        {
            if (m.Value.Length > 0)
            {
                string url = m.Value.Substring(m.Value.IndexOf("u"), m.Value.Length - m.Value.IndexOf("u"));
                EC.FileObj.FileDel("../" + url);
            }
        }
        return outStr;

    }
    /// <summary>
    /// 下载远程图片
    /// </summary>
    /// <param name="strUrl">将要下载的图片地址</param>
    /// <returns>返回string类型;图片的本地地址</returns>
    public static string downRemoteImg(string savedir, string imgpath)
    {
        if (string.IsNullOrEmpty(imgpath))
            return string.Empty;
        else
        {
            string imgName = string.Empty;
            string imgExt = string.Empty;
            string saveFilePath = string.Empty;
            imgName = DateTime.UtcNow.ToString("yyyy" + "MM" + "dd" + "HH" + "mm" + "ss" + "ffffff");
            imgExt = imgpath.Substring(imgpath.LastIndexOf("."), imgpath.Length - imgpath.LastIndexOf("."));
            saveFilePath = System.Web.HttpContext.Current.Server.MapPath(savedir);
            if (!Directory.Exists(saveFilePath))
                Directory.CreateDirectory(saveFilePath);
            try
            {
                WebRequest wreq = WebRequest.Create(imgpath);
                wreq.Timeout = 10000;
                HttpWebResponse wresp = (HttpWebResponse)wreq.GetResponse();
                Stream s = wresp.GetResponseStream();
                System.Drawing.Image img;
                img = System.Drawing.Image.FromStream(s);
                switch (imgExt.ToLower())
                {
                    case ".gif":
                        img.Save(saveFilePath + imgName + imgExt, ImageFormat.Gif);
                        break;
                    case ".jpg":
                    case ".jpeg":
                        img.Save(saveFilePath + imgName + imgExt, ImageFormat.Jpeg);
                        break;
                    case ".png":
                        img.Save(saveFilePath + imgName + imgExt, ImageFormat.Png);
                        break;
                    case ".icon":
                        img.Save(saveFilePath + imgName + imgExt, ImageFormat.Icon);
                        break;
                    case ".bmp":
                        img.Save(saveFilePath + imgName + imgExt, ImageFormat.Bmp);
                        break;
                }

                img.Dispose();
                s.Dispose();
                return savedir + imgName + imgExt;
            }
            catch
            {
                return imgpath;
            }
        }
    }
    public static string stringformat(string str, int n)
    {
        ///
        ///格式化字符串长度，超出部分显示省略号,区分汉字跟字母。汉字2个字节，字母数字一个字节
        ///
        string temp = string.Empty;
        if (System.Text.Encoding.Default.GetByteCount(str) <= n)//如果长度比需要的长度n小,返回原字符串
        {
            return str;
        }
        else
        {
            int t = 0;
            char[] q = str.ToCharArray();
            for (int i = 0; i < q.Length && t < n; i++)
            {
                if ((int)q[i] >= 0x4E00 && (int)q[i] <= 0x9FA5)//是否汉字
                {
                    temp += q[i];
                    t += 2;
                }
                else
                {
                    temp += q[i];
                    t++;
                }
            }
            return (temp + "...");
        }
    }

}

