﻿using System;
using System.IO;
using System.Web.Security;
using System.Web.UI;

public class XVPage : Page
{
    static private DirectoryInfo _Dir;

    private DirectoryInfo Dir
    {
        get
        {
            if (_Dir == null)
            {
                _Dir = new DirectoryInfo(Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "App_Data"));
                if (!_Dir.Exists)
                    _Dir.Create();
                _Dir = new DirectoryInfo(Path.Combine(_Dir.FullName, "ViewState"));
                if (!_Dir.Exists)
                    _Dir.Create();
            }
            return _Dir;
        }
    }

    protected override object LoadPageStateFromPersistenceMedium()
    {
        PageStatePersister ps = this.PageStatePersister;
        ps.Load();
        if (ps.ControlState != null)
            ps.ControlState = 反序列化对象((string)ps.ControlState);
        if (ps.ViewState != null)
            ps.ViewState = 反序列化对象((string)ps.ViewState);
        return new Pair(ps.ControlState, ps.ViewState);
    }

    protected override void SavePageStateToPersistenceMedium(object state)
    {
        PageStatePersister ps = this.PageStatePersister;
        if (state is Pair)
        {
            Pair pair = (Pair)state;
            ps.ControlState = pair.First;
            ps.ViewState = pair.Second;
        }
        else
        {
            ps.ViewState = state;
        }
        if (ps.ControlState != null)
            ps.ControlState = 序列化对象(ps.ControlState);
        if (ps.ViewState != null)
            ps.ViewState = 序列化对象(ps.ViewState);
        ps.Save();
    }

    private object 反序列化对象(string stateID)
    {
        string stateStr = (string)Cache[stateID];
        string file = Path.Combine(Dir.FullName, stateID);
        if (stateStr == null)
            stateStr = File.ReadAllText(file);
        else
            Cache.Remove(stateID);
        return new ObjectStateFormatter().Deserialize(stateStr);
    }

    private string 序列化对象(object obj)
    {
        string value = new ObjectStateFormatter().Serialize(obj);
        string stateID = (DateTime.Now.Ticks + (long)value.GetHashCode()).ToString(); //产生离散的id号码   
        File.WriteAllText(Path.Combine(Dir.FullName, stateID), value);
        Cache.Insert(stateID, value);
        return stateID;
    }

    protected override void OnUnload(EventArgs e)
    {
        base.OnUnload(e);
        DateTime dt = DateTime.Now.AddMinutes(-20);
        foreach (FileInfo fl in Dir.GetFiles())
            if (fl.LastAccessTime < dt)
                try
                {
                    fl.Delete();
                }
                catch
                {
                }
    }
}
public class Memberlogin : Page
{
    // Methods
    protected override void OnLoad(EventArgs e)
    {
        if (Session["member"] == null)
        {
            Response.Redirect("login.aspx");
        }
        base.OnLoad(e);
    }
}
public class RePage : Page
{
    public RePage()
    {
        base.Load += new EventHandler(RePage_Load);
    }
    private void RePage_Load(object sender, EventArgs e)
    {
        if (!IsAdminLogin())
        {
            Response.Write("<script>parent.location.href='login.aspx'</script>");
            Response.End();
        }
        else
        {
            string path = Request.Path.ToLower();
            if (path.Contains("ensystem"))
            {
                DBUtility.DbHelperOleDb.connectionString = theconnectstring.enconstring;
            }
            else
            {
                DBUtility.DbHelperOleDb.connectionString = theconnectstring.constring;
            }
            siteconfig.Reinit();
        }
    }
    public bool IsAdminLogin()
    {
        bool result;
        if (Session["check"] != null)
        {
            result = true;
        }
        else
        {
            string adminname = Utils.GetCookie("AdminName", "nnon");
            string adminpwd = Utils.GetCookie("AdminPwd", "nnon");
            if (adminname != "" && adminpwd != "")
            {
                logo mylo = new logo();
                if (mylo.logoin(adminname, FormsAuthentication.HashPasswordForStoringInConfigFile(adminpwd, "MD5")))
                {
                    Session["check"] = adminname;
                    result = true;
                    return result;
                }
            }
            result = false;
        }
        return result;
    }
    //// Methods
    //protected override void OnLoad(EventArgs e)
    //{
    //    if (Session["check"] == null)
    //    {
    //        Response.Redirect("login.aspx");
    //    }
    //    if (!IsAdminLogin())
    //    {
    //        base.Response.Write("<script>parent.location.href='" + this.siteConfig.webpath + this.siteConfig.webmanagepath + "/login.aspx'</script>");
    //        base.Response.End();
    //    }
    //    else
    //    {
    //        string path = Request.Path.ToLower();
    //        if (path.Contains("ensystem"))
    //        {
    //            DBUtility.DbHelperOleDb.connectionString = theconnectstring.enconstring;
    //        }
    //        else
    //        {
    //            DBUtility.DbHelperOleDb.connectionString = theconnectstring.constring;
    //        }
    //        siteconfig.Reinit();
    //    }
    //    base.OnLoad(e);
    //}
    //protected override void OnUnload(System.EventArgs e)
    //{
    //    System.GC.Collect();
    //    base.OnUnload(e);
    //}
}
//中文版
public class Version : Page
{
    protected override void OnLoad(System.EventArgs e)
    {
        string path = Request.Path.ToLower();
        if (path.Contains("english"))
        {
            DBUtility.DbHelperOleDb.connectionString = theconnectstring.enconstring;
        }
        else
        {
            DBUtility.DbHelperOleDb.connectionString = theconnectstring.constring;
        }
        seohelper.Reinit();
        siteconfig.Reinit();
        base.OnLoad(e);
    }

    protected override void OnUnload(System.EventArgs e)
    {
        System.GC.Collect();
        base.OnUnload(e);
    }
}


//中文版
public class Versions : MasterPage
{
    protected override void OnLoad(System.EventArgs e)
    {
        string path = Request.Path.ToLower();
        if (path.Contains("english"))
        {
            DBUtility.DbHelperOleDb.connectionString = theconnectstring.enconstring;
        }
        else
        {
            DBUtility.DbHelperOleDb.connectionString = theconnectstring.constring;
        }
        seohelper.Reinit();
        siteconfig.Reinit();
        base.OnLoad(e);
    }
    protected override void OnUnload(System.EventArgs e)
    {
        System.GC.Collect();
        base.OnUnload(e);
    }
}


